@@ -151,7 +151,9 @@ async def start_gateway(descriptor: FileDescriptor, port: int = 7070):
                        allow_credentials=True)
     app.add_exception_handler(HTTPException, http_exception)
     app.add_route("/metrics/", metrics)
-    channel = insecure_channel('localhost:8080')
+    max_length = 512 * 1024 * 1024
+    client_options = [('grpc.max_send_message_length', max_length), ('grpc.max_receive_message_length', max_length)]
+    channel = insecure_channel('localhost:8080', options=client_options)
     config = Config()
     config.bind = [f'0.0.0.0:{port}']
     for service_name in descriptor.services_by_name.keys():
